package com.aucma.production.service;

import java.util.List;

import com.aucma.production.domain.ProdRoute;

public interface IProdRouteService {
    ProdRoute selectProdRouteByObjId(Long objId);

    List<ProdRoute> selectProdRouteList(ProdRoute prodRoute);

    int insertProdRoute(ProdRoute prodRoute);

    int updateProdRoute(ProdRoute prodRoute);

    int deleteProdRouteByObjIds(Long[] objIds);
}
