package com.aucma.production.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.production.domain.ProdRoute;
import com.aucma.production.service.IProdRouteService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/production/processRoute")
public class ProdRouteController extends BaseController {
    @Autowired
    private IProdRouteService prodRouteService;

    @PreAuthorize("@ss.hasPermi('production:processRoute:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdRoute prodRoute) {
        startPage();
        List<ProdRoute> list = prodRouteService.selectProdRouteList(prodRoute);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('production:processRoute:export')")
    @Log(title = "生产工艺路线", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdRoute prodRoute) {
        List<ProdRoute> list = prodRouteService.selectProdRouteList(prodRoute);
        ExcelUtil<ProdRoute> util = new ExcelUtil<ProdRoute>(ProdRoute.class);
        util.exportExcel(response, list, "生产工艺路线数据");
    }

    @PreAuthorize("@ss.hasPermi('production:processRoute:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodRouteService.selectProdRouteByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('production:processRoute:add')")
    @Log(title = "生产工艺路线", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdRoute prodRoute) {
        prodRoute.setCreatedBy(getUsername());
        return toAjax(prodRouteService.insertProdRoute(prodRoute));
    }

    @PreAuthorize("@ss.hasPermi('production:processRoute:edit')")
    @Log(title = "生产工艺路线", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdRoute prodRoute) {
        prodRoute.setUpdatedBy(getUsername());
        return toAjax(prodRouteService.updateProdRoute(prodRoute));
    }

    @PreAuthorize("@ss.hasPermi('production:processRoute:remove')")
    @Log(title = "生产工艺路线", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodRouteService.deleteProdRouteByObjIds(objIds));
    }
}
